import React, { useEffect, useRef, useState, useImperativeHandle, useCallback } from 'react';
import 'jb-switch';

function useEvent(dom, event, handler) {
  var passive = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
  useEffect(function () {
    if (dom) {
      // initiate the event handler
      dom.addEventListener(event, handler, passive);
    }
    // this will clean up the event every time the component is re-rendered
    return function cleanup() {
      if (dom) {
        dom.removeEventListener(event, handler, passive);
      }
    };
  });
}

const JBSwitch = React.forwardRef((props, ref) => {
    const element = useRef(null);
    const [refChangeCount, refChangeCountSetter] = useState(0);
    useImperativeHandle(ref, () => (element ? element.current : {}), [element]);
    useEffect(() => {
        refChangeCountSetter(refChangeCount + 1);
    }, [element.current]);
    const onchange = useCallback((e) => {
        if (props.value !== undefined && props.value !== null) {
            e.preventDefault();
        }
        if (typeof props.onChange == "function") {
            props.onChange(e);
        }
    }, [props.onChange, props.value]);
    useEvent(element.current, 'before-change', onchange, true);
    // useEvent(element.current, 'change', onchange, true);
    useEffect(() => {
        if (element.current && props.isLoading !== undefined && props.isLoading !== null && typeof props.isLoading == "boolean") {
            element.current.isLoading = props.isLoading;
        }
    }, [props.isLoading]);
    useEffect(() => {
        if (element.current && props.value !== null && props.value !== undefined) {
            element.current.value = props.value;
        }
    }, [props.value]);
    useEffect(() => {
        if (element.current && typeof props.style == "string") {
            element.current.setAttribute("style", props.style);
        }
    }, [props.style]);
    return (React.createElement("jb-switch", { class: props.className ? props.className : "", name: props.name, "true-title": props.trueTitle ? props.trueTitle : '', "false-title": props.falseTitle ? props.falseTitle : '', ref: element }));
});
JBSwitch.displayName = "JBSwitch";

export { JBSwitch };
//# sourceMappingURL=JBSwitch.js.map
