(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('jb-switch')) :
    typeof define === 'function' && define.amd ? define(['exports', 'react', 'jb-switch'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.JBSwitch = {}, global.React));
})(this, (function (exports, React) { 'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

    function useEvent(dom, event, handler) {
      var passive = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
      React.useEffect(function () {
        if (dom) {
          // initiate the event handler
          dom.addEventListener(event, handler, passive);
        }
        // this will clean up the event every time the component is re-rendered
        return function cleanup() {
          if (dom) {
            dom.removeEventListener(event, handler, passive);
          }
        };
      });
    }

    const JBSwitch = React__default["default"].forwardRef((props, ref) => {
        const element = React.useRef(null);
        const [refChangeCount, refChangeCountSetter] = React.useState(0);
        React.useImperativeHandle(ref, () => (element ? element.current : {}), [element]);
        React.useEffect(() => {
            refChangeCountSetter(refChangeCount + 1);
        }, [element.current]);
        const onchange = React.useCallback((e) => {
            if (props.value !== undefined && props.value !== null) {
                e.preventDefault();
            }
            if (typeof props.onChange == "function") {
                props.onChange(e);
            }
        }, [props.onChange, props.value]);
        useEvent(element.current, 'before-change', onchange, true);
        // useEvent(element.current, 'change', onchange, true);
        React.useEffect(() => {
            if (element.current && props.isLoading !== undefined && props.isLoading !== null && typeof props.isLoading == "boolean") {
                element.current.isLoading = props.isLoading;
            }
        }, [props.isLoading]);
        React.useEffect(() => {
            if (element.current && props.value !== null && props.value !== undefined) {
                element.current.value = props.value;
            }
        }, [props.value]);
        React.useEffect(() => {
            if (element.current && typeof props.style == "string") {
                element.current.setAttribute("style", props.style);
            }
        }, [props.style]);
        return (React__default["default"].createElement("jb-switch", { class: props.className ? props.className : "", name: props.name, "true-title": props.trueTitle ? props.trueTitle : '', "false-title": props.falseTitle ? props.falseTitle : '', ref: element }));
    });
    JBSwitch.displayName = "JBSwitch";

    exports.JBSwitch = JBSwitch;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=JBSwitch.umd.js.map
